@@ -18,7 +18,7 @@ fn run(bencher: &mut Bencher) {
             exit 0
             "#,
             &args,
-            &options
+            &options,
         ).unwrap();
 
         assert_eq!(code, 0);
