@@ -1,29 +1,26 @@
 #![deny(
-    absolute_path_starting_with_module, anonymous_parameters, box_pointers, const_err, dead_code,
-    deprecated, elided_lifetime_in_path, exceeding_bitshifts,
+    anonymous_parameters, const_err, dead_code, deprecated, exceeding_bitshifts,
     illegal_floating_point_literal_pattern, improper_ctypes, incoherent_fundamental_impls,
     invalid_type_param_default, late_bound_lifetime_arguments, legacy_constructor_visibility,
-    legacy_directory_ownership, legacy_imports, missing_copy_implementations,
-    missing_debug_implementations, missing_docs, missing_fragment_specifier, mutable_transmutes,
-    no_mangle_const_items, no_mangle_generic_items, non_camel_case_types,
-    non_shorthand_field_patterns, non_snake_case, non_upper_case_globals, overflowing_literals,
-    parenthesized_params_in_types_and_modules, path_statements, patterns_in_fns_without_body,
-    plugin_as_library, private_in_public, private_no_mangle_fns, private_no_mangle_statics,
-    pub_use_of_private_extern_crate, renamed_and_removed_lints, safe_extern_statics,
-    safe_packed_borrows, single_use_lifetime, stable_features, trivial_casts, trivial_numeric_casts,
-    type_alias_bounds, tyvar_behind_raw_pointer, unconditional_recursion, unions_with_drop_fields,
-    unknown_crate_types, unreachable_code, unreachable_patterns, unreachable_pub, unsafe_code,
-    unstable_features, unstable_name_collision, unused_allocation, unused_assignments,
-    unused_attributes, unused_comparisons, unused_doc_comment, unused_extern_crates,
-    unused_features, unused_import_braces, unused_imports, unused_macros, unused_must_use,
-    unused_mut, unused_parens, unused_qualifications, unused_results, unused_unsafe,
-    unused_variables, variant_size_differences, while_true
+    legacy_directory_ownership, missing_copy_implementations, missing_docs,
+    missing_fragment_specifier, mutable_transmutes, no_mangle_const_items, no_mangle_generic_items,
+    non_camel_case_types, non_shorthand_field_patterns, non_snake_case, non_upper_case_globals,
+    overflowing_literals, parenthesized_params_in_types_and_modules, path_statements,
+    patterns_in_fns_without_body, plugin_as_library, private_in_public, private_no_mangle_fns,
+    private_no_mangle_statics, pub_use_of_private_extern_crate, safe_extern_statics,
+    safe_packed_borrows, stable_features, trivial_casts, trivial_numeric_casts, type_alias_bounds,
+    tyvar_behind_raw_pointer, unconditional_recursion, unions_with_drop_fields, unknown_crate_types,
+    unreachable_code, unreachable_patterns, unreachable_pub, unsafe_code, unstable_features,
+    unstable_name_collisions, unused_allocation, unused_assignments, unused_attributes,
+    unused_comparisons, unused_doc_comments, unused_extern_crates, unused_features,
+    unused_import_braces, unused_imports, unused_macros, unused_must_use, unused_mut, unused_parens,
+    unused_qualifications, unused_unsafe, unused_variables, while_true
 )]
 #![warn(unknown_lints)]
 #![allow(
-    bare_trait_object, box_pointers, elided_lifetime_in_path, missing_debug_implementations,
-    single_use_lifetime, trivial_casts, unnecessary_extern_crate, unused_results,
-    variant_size_differences, warnings
+    bare_trait_objects, box_pointers, elided_lifetimes_in_paths, missing_debug_implementations,
+    single_use_lifetimes, unused_results, variant_size_differences, warnings,
+    renamed_and_removed_lints
 )]
 #![cfg_attr(feature = "clippy", feature(plugin))]
 
